@@ -217,7 +217,7 @@ long
 buf_Sync(int quitOnShutdown) 
 {
     cm_buf_t **bpp, *bp, *prevbp;
-    long wasDirty = 0;
+    afs_uint32 wasDirty = 0;
     cm_req_t req;
 
     /* go through all of the dirty buffers */
@@ -232,14 +232,27 @@ buf_Sync(int quitOnShutdown)
         */
         lock_ObtainMutex(&bp->mx);
 
-        if (bp->flags & CM_BUF_DIRTY) {
+        if (bp->flags & CM_BUF_DIRTY && !(bp->flags & CM_BUF_REDIR)) {
             /* start cleaning the buffer; don't touch log pages since
-            * the log code counts on knowing exactly who is writing
-            * a log page at any given instant.
-            */
-            cm_InitReq(&req);
-            req.flags |= CM_REQ_NORETRY;
-            wasDirty |= buf_CleanAsyncLocked(bp, &req);
+             * the log code counts on knowing exactly who is writing
+             * a log page at any given instant.
+             *
+             * only attempt to write the buffer if the volume might
+             * be online.
+             */
+            afs_uint32 dirty;
+            cm_volume_t * volp;
+
+            volp = cm_GetVolumeByFID(&bp->fid);
+            switch (cm_GetVolumeStatus(volp, bp->fid.volume)) {
+            case vl_online:
+            case vl_unknown:
+                cm_InitReq(&req);
+                req.flags |= CM_REQ_NORETRY;
+                buf_CleanAsyncLocked(bp, &req, &dirty);
+                wasDirty |= dirty;
+            }
+            cm_PutVolume(volp);
         }
 
         /* the buffer may or may not have been dirty
@@ -265,6 +278,34 @@ buf_Sync(int quitOnShutdown)
             buf_ReleaseLocked(bp, TRUE);
             lock_ConvertWToR(&buf_globalLock);
         } else {
+            if (buf_ShutdownFlag) {
+                cm_cell_t *cellp;
+                cm_volume_t *volp;
+                char volstr[VL_MAXNAMELEN+12]="";
+                char *ext = "";
+
+                volp = cm_GetVolumeByFID(&bp->fid);
+                if (volp) {
+                    cellp = volp->cellp;
+                    if (bp->fid.volume == volp->vol[RWVOL].ID)
+                        ext = "";
+                    else if (bp->fid.volume == volp->vol[ROVOL].ID)
+                        ext = ".readonly";
+                    else if (bp->fid.volume == volp->vol[BACKVOL].ID)
+                        ext = ".backup";
+                    else
+                        ext = ".nomatch";
+                    snprintf(volstr, sizeof(volstr), "%s%s", volp->namep, ext);
+                } else {
+                    cellp = cm_FindCellByID(bp->fid.cell, CM_FLAG_NOPROBE);
+                    snprintf(volstr, sizeof(volstr), "%u", bp->fid.volume);
+                }
+
+                LogEvent(EVENTLOG_INFORMATION_TYPE, MSG_DIRTY_BUFFER_AT_SHUTDOWN, 
+                         cellp->name, volstr, bp->fid.vnode, bp->fid.unique, 
+                         bp->offset.QuadPart+bp->dirty_offset, bp->dirty_length);
+            }
+
             /* advance the pointer so we don't loop forever */
             lock_ObtainRead(&buf_globalLock);
             bpp = &bp->dirtyp;
@@ -289,7 +330,9 @@ void buf_IncrSyncer(long parm)
 	    i = SleepEx(5000, 1);
 	    if (i != 0) 
                 continue;
-	}
+	} else {
+            Sleep(50);
+        }
 
         wasDirty = buf_Sync(1);
     } /* whole daemon's while loop */
@@ -506,7 +549,6 @@ long buf_Init(int newFile, cm_buf_ops_t *opsp, afs_uint64 nbuffers)
  */
 long buf_AddBuffers(afs_uint64 nbuffers)
 {
-#ifndef DJGPP
     /* The size of a virtual cache cannot be changed after it has
      * been created.  Subsequent calls to MapViewofFile() with
      * an existing mapping object name would not allow the 
@@ -520,43 +562,6 @@ long buf_AddBuffers(afs_uint64 nbuffers)
               nbuffers, cm_data.buf_nbuffers);
 
     return CM_ERROR_INVAL;
-#else
-    cm_buf_t *bp;
-    int i;
-    char *data;
-
-    data = malloc(buf_nbuffers * cm_data.buf_blockSize);
-
-    /* Create buffer headers and put in free list */
-    bp = malloc(nbuffers * sizeof(*bp));
-
-    for (i=0; i<nbuffers; i++) {
-        memset(bp, 0, sizeof(*bp));
-        
-        lock_InitializeMutex(&bp->mx, "cm_buf_t", LOCK_HIERARCHY_BUFFER);
-
-        /* grab appropriate number of bytes from aligned zone */
-        bp->datap = data;
-
-        bp->flags |= CM_BUF_INLRU;
-
-        lock_ObtainWrite(&buf_globalLock);
-        /* note that buf_allp chain is covered by buf_globalLock now */
-        bp->allp = cm_data.buf_allp;
-        cm_data.buf_allp = bp;
-        osi_QAdd((osi_queue_t **) &cm_data.buf_freeListp, &bp->q);
-        if (!cm_data.buf_freeListEndp) 
-            cm_data.buf_freeListEndp = bp;
-        cm_data.buf_nbuffers++;
-        lock_ReleaseWrite(&buf_globalLock);
-
-        bp++;
-        data += cm_data.buf_blockSize;
-	
-    }	 /* for loop over all buffers */
-
-    return 0;
-#endif /* DJGPP */
 }       
 
 /* interface to set the number of buffers to an exact figure.
@@ -605,7 +610,7 @@ void buf_WaitIO(cm_scache_t * scp, cm_buf_t *bp)
         }
         osi_SleepM((LONG_PTR)bp, &bp->mx);
 
-	smb_UpdateServerPriority();
+	cm_UpdateServerPriority();
 
         lock_ObtainMutex(&bp->mx);
         osi_Log1(buf_logp, "buf_WaitIO conflict wait done for 0x%p", bp);
@@ -679,6 +684,54 @@ cm_buf_t *buf_Find(struct cm_scache *scp, osi_hyper_t *offsetp)
     return bp;
 }       
 
+/* find a buffer, if any, for a particular file ID and offset.  Assumes
+ * that buf_globalLock is write locked when called.  Uses the all buffer
+ * list.
+ */
+cm_buf_t *buf_FindAllLocked(struct cm_scache *scp, osi_hyper_t *offsetp, afs_uint32 flags)
+{
+    cm_buf_t *bp;
+
+    if (flags == 0) {
+        for(bp = cm_data.buf_allp; bp; bp=bp->allp) {
+            if (cm_FidCmp(&scp->fid, &bp->fid) == 0
+                 && offsetp->LowPart == bp->offset.LowPart
+                 && offsetp->HighPart == bp->offset.HighPart) {
+                buf_HoldLocked(bp);
+                break;
+            }
+        }
+    } else {
+        for(bp = cm_data.buf_allp; bp; bp=bp->allp) {
+            if (cm_FidCmp(&scp->fid, &bp->fid) == 0) {
+                char * fileOffset;
+                
+                fileOffset = offsetp->QuadPart + cm_data.baseAddress;
+                if (fileOffset == bp->datap) {
+                    buf_HoldLocked(bp);
+                    break;
+                }
+            }
+        }
+    }
+    /* return whatever we found, if anything */
+    return bp;
+}
+
+/* find a buffer with offset *offsetp for vnode *scp.  Called
+ * with no locks held.  Use the all buffer list.
+ */
+cm_buf_t *buf_FindAll(struct cm_scache *scp, osi_hyper_t *offsetp, afs_uint32 flags)
+{
+    cm_buf_t *bp;
+
+    lock_ObtainRead(&buf_globalLock);
+    bp = buf_FindAllLocked(scp, offsetp, flags);
+    lock_ReleaseRead(&buf_globalLock);
+
+    return bp;
+}       
+
 /* start cleaning I/O on this buffer.  Buffer must be write locked, and is returned
  * write-locked.
  *
@@ -688,10 +741,10 @@ cm_buf_t *buf_Find(struct cm_scache *scp, osi_hyper_t *offsetp)
  *
  * Returns non-zero if the buffer was dirty.
  */
-long buf_CleanAsyncLocked(cm_buf_t *bp, cm_req_t *reqp)
+afs_uint32 buf_CleanAsyncLocked(cm_buf_t *bp, cm_req_t *reqp, afs_uint32 *pisdirty)
 {
-    long code = 0;
-    long isdirty = 0;
+    afs_uint32 code = 0;
+    afs_uint32 isdirty = 0;
     cm_scache_t * scp = NULL;
     osi_hyper_t offset;
 
@@ -756,15 +809,15 @@ long buf_CleanAsyncLocked(cm_buf_t *bp, cm_req_t *reqp)
 	 */
 	if (reqp->flags & CM_REQ_NORETRY)
 	    break;
-    };
-
-    if (!(bp->flags & CM_BUF_DIRTY)) {
-	/* remove buffer from dirty buffer queue */
 
+        /* Ditto if the hardDeadTimeout or idleTimeout was reached */
+        if (code == CM_ERROR_TIMEDOUT || code == CM_ERROR_ALLDOWN ||
+            code == CM_ERROR_ALLBUSY || code == CM_ERROR_ALLOFFLINE ||
+            code == CM_ERROR_CLOCKSKEW) {
+            break;
+        }
     }
 
-    /* do logging after call to GetLastError, or else */
-        
     /* if someone was waiting for the I/O that just completed or failed,
      * wake them up.
      */
@@ -773,7 +826,11 @@ long buf_CleanAsyncLocked(cm_buf_t *bp, cm_req_t *reqp)
         osi_Log1(buf_logp, "buf_WaitIO Waking bp 0x%p", bp);
         osi_Wakeup((LONG_PTR) bp);
     }
-    return isdirty;
+
+    if (pisdirty)
+        *pisdirty = isdirty;
+
+    return code;
 }
 
 /* Called with a zero-ref count buffer and with the buf_globalLock write locked.
@@ -852,14 +909,11 @@ void buf_Recycle(cm_buf_t *bp)
  * space from the buffer pool.  In that case, the buffer will be returned
  * without being hashed into the hash table.
  */
-long buf_GetNewLocked(struct cm_scache *scp, osi_hyper_t *offsetp, cm_buf_t **bufpp)
+long buf_GetNewLocked(struct cm_scache *scp, osi_hyper_t *offsetp, cm_req_t *reqp, cm_buf_t **bufpp)
 {
     cm_buf_t *bp;	/* buffer we're dealing with */
     cm_buf_t *nextBp;	/* next buffer in file hash chain */
     afs_uint32 i;	/* temp */
-    cm_req_t req;
-
-    cm_InitReq(&req);	/* just in case */
 
 #ifdef TESTING
     buf_ValidateBufQueues();
@@ -960,7 +1014,7 @@ long buf_GetNewLocked(struct cm_scache *scp, osi_hyper_t *offsetp, cm_buf_t **bu
                  * have the WRITING flag set, so we won't get
                  * back here.
                  */
-                buf_CleanAsync(bp, &req);
+                buf_CleanAsync(bp, reqp, NULL);
 
                 /* now put it back and go around again */
                 buf_Release(bp);
@@ -1052,7 +1106,7 @@ long buf_GetNewLocked(struct cm_scache *scp, osi_hyper_t *offsetp, cm_buf_t **bu
 /* get a page, returning it held but unlocked.  Doesn't fill in the page
  * with I/O, since we're going to write the whole thing new.
  */
-long buf_GetNew(struct cm_scache *scp, osi_hyper_t *offsetp, cm_buf_t **bufpp)
+long buf_GetNew(struct cm_scache *scp, osi_hyper_t *offsetp, cm_req_t *reqp, cm_buf_t **bufpp)
 {
     cm_buf_t *bp;
     long code;
@@ -1071,7 +1125,7 @@ long buf_GetNew(struct cm_scache *scp, osi_hyper_t *offsetp, cm_buf_t **bufpp)
         }
 
         /* otherwise, we have to create a page */
-        code = buf_GetNewLocked(scp, &pageOffset, &bp);
+        code = buf_GetNewLocked(scp, &pageOffset, reqp, &bp);
 
         /* check if the buffer was created in a race condition branch.
          * If so, go around so we can hold a reference to it. 
@@ -1104,7 +1158,7 @@ long buf_GetNew(struct cm_scache *scp, osi_hyper_t *offsetp, cm_buf_t **bufpp)
 
 /* get a page, returning it held but unlocked.  Make sure it is complete */
 /* The scp must be unlocked when passed to this function */
-long buf_Get(struct cm_scache *scp, osi_hyper_t *offsetp, cm_buf_t **bufpp)
+long buf_Get(struct cm_scache *scp, osi_hyper_t *offsetp, cm_req_t *reqp, cm_buf_t **bufpp)
 {
     cm_buf_t *bp;
     long code;
@@ -1138,7 +1192,7 @@ long buf_Get(struct cm_scache *scp, osi_hyper_t *offsetp, cm_buf_t **bufpp)
         }
 
         /* otherwise, we have to create a page */
-        code = buf_GetNewLocked(scp, &pageOffset, &bp);
+        code = buf_GetNewLocked(scp, &pageOffset, reqp, &bp);
 	/* bp->mx is now held */
 
         /* check if the buffer was created in a race condition branch.
@@ -1178,9 +1232,7 @@ long buf_Get(struct cm_scache *scp, osi_hyper_t *offsetp, cm_buf_t **bufpp)
 
         if (code != 0) {
             /* failure or queued */
-#ifndef DJGPP   /* cm_bufRead always returns 0 */
             if (code != ERROR_IO_PENDING) {
-#endif
                 bp->error = code;
                 bp->flags |= CM_BUF_ERROR;
                 bp->flags &= ~CM_BUF_READING;
@@ -1194,9 +1246,7 @@ long buf_Get(struct cm_scache *scp, osi_hyper_t *offsetp, cm_buf_t **bufpp)
                 buf_ValidateBufQueues();
 #endif /* TESTING */
                 return code;
-#ifndef DJGPP
             }
-#endif
         } else {
             /* otherwise, I/O completed instantly and we're done, except
              * for padding the xfr out with 0s and checking for EOF
@@ -1272,13 +1322,13 @@ long buf_CountFreeList(void)
 }
 
 /* clean a buffer synchronously */
-long buf_CleanAsync(cm_buf_t *bp, cm_req_t *reqp)
+afs_uint32 buf_CleanAsync(cm_buf_t *bp, cm_req_t *reqp, afs_uint32 *pisdirty)
 {
     long code;
     osi_assertx(bp->magic == CM_BUF_MAGIC, "invalid cm_buf_t magic");
 
     lock_ObtainMutex(&bp->mx);
-    code = buf_CleanAsyncLocked(bp, reqp);
+    code = buf_CleanAsyncLocked(bp, reqp, pisdirty);
     lock_ReleaseMutex(&bp->mx);
 
     return code;
@@ -1409,7 +1459,7 @@ long buf_CleanAndReset(void)
                 cm_InitReq(&req);
 		req.flags |= CM_REQ_NORETRY;
 
-		buf_CleanAsync(bp, &req);
+		buf_CleanAsync(bp, &req, NULL);
 		buf_CleanWait(NULL, bp, FALSE);
 
                 /* relock and release buffer */
@@ -1623,7 +1673,7 @@ long buf_FlushCleanPages(cm_scache_t *scp, cm_user_t *userp, cm_req_t *reqp)
             lock_ObtainMutex(&bp->mx);
 
             /* start cleaning the buffer, and wait for it to finish */
-            buf_CleanAsyncLocked(bp, reqp);
+            buf_CleanAsyncLocked(bp, reqp, NULL);
             buf_WaitIO(scp, bp);
             lock_ReleaseMutex(&bp->mx);
 
@@ -1741,7 +1791,7 @@ long buf_CleanVnode(struct cm_scache *scp, cm_user_t *userp, cm_req_t *reqp)
         if (cm_FidCmp(&bp->fid, &scp->fid) == 0) {
             lock_ObtainMutex(&bp->mx);
             if (bp->flags & CM_BUF_DIRTY) {
-                if (userp) {
+                if (userp && userp != bp->userp) {
                     cm_HoldUser(userp);
                     if (bp->userp) 
                         cm_ReleaseUser(bp->userp);
@@ -1770,8 +1820,17 @@ long buf_CleanVnode(struct cm_scache *scp, cm_user_t *userp, cm_req_t *reqp)
                     bp->dataVersion = CM_BUF_VERSION_BAD;
                     bp->dirtyCounter++;
                     break;
+                case CM_ERROR_TIMEDOUT:
+                case CM_ERROR_ALLDOWN:
+                case CM_ERROR_ALLBUSY:
+                case CM_ERROR_ALLOFFLINE:
+                case CM_ERROR_CLOCKSKEW:
+                    /* do not mark the buffer in error state but do
+                     * not attempt to complete the rest either.
+                     */
+                    break;
                 default:
-                    wasDirty = buf_CleanAsyncLocked(bp, reqp);
+                    code = buf_CleanAsyncLocked(bp, reqp, &wasDirty);
                     if (bp->flags & CM_BUF_ERROR) {
                         code = bp->error;
                         if (code == 0)
@@ -1862,11 +1921,11 @@ int cm_DumpBufHashTable(FILE *outputFile, char *cookie, int lock)
 	    StringCbPrintfA(output, sizeof(output), 
 			    "%s bp=0x%08X, hash=%d, fid (cell=%d, volume=%d, "
 			    "vnode=%d, unique=%d), offset=%x:%08x, dv=%I64d, "
-			    "flags=0x%x, cmFlags=0x%x, refCount=%d\r\n",
+			    "flags=0x%x, cmFlags=0x%x, error=0x%x, refCount=%d\r\n",
 			     cookie, (void *)bp, i, bp->fid.cell, bp->fid.volume, 
 			     bp->fid.vnode, bp->fid.unique, bp->offset.HighPart, 
 			     bp->offset.LowPart, bp->dataVersion, bp->flags, 
-			     bp->cmFlags, bp->refCount);
+			     bp->cmFlags, bp->error, bp->refCount);
 	    WriteFile(outputFile, output, (DWORD)strlen(output), &zilch, NULL);
         }
     }
@@ -1880,11 +1939,11 @@ int cm_DumpBufHashTable(FILE *outputFile, char *cookie, int lock)
 	StringCbPrintfA(output, sizeof(output), 
 			 "%s bp=0x%08X, fid (cell=%d, volume=%d, "
 			 "vnode=%d, unique=%d), offset=%x:%08x, dv=%I64d, "
-			 "flags=0x%x, cmFlags=0x%x, refCount=%d\r\n",
+			 "flags=0x%x, cmFlags=0x%x, error=0x%x, refCount=%d\r\n",
 			 cookie, (void *)bp, bp->fid.cell, bp->fid.volume, 
 			 bp->fid.vnode, bp->fid.unique, bp->offset.HighPart, 
 			 bp->offset.LowPart, bp->dataVersion, bp->flags, 
-			 bp->cmFlags, bp->refCount);
+			 bp->cmFlags, bp->error, bp->refCount);
 	WriteFile(outputFile, output, (DWORD)strlen(output), &zilch, NULL);
     }
     StringCbPrintfA(output, sizeof(output), "%s - Done dumping buf_FreeListEndp.\r\n", cookie);
@@ -1896,11 +1955,11 @@ int cm_DumpBufHashTable(FILE *outputFile, char *cookie, int lock)
 	StringCbPrintfA(output, sizeof(output), 
 			 "%s bp=0x%08X, fid (cell=%d, volume=%d, "
 			 "vnode=%d, unique=%d), offset=%x:%08x, dv=%I64d, "
-			 "flags=0x%x, cmFlags=0x%x, refCount=%d\r\n",
+			 "flags=0x%x, cmFlags=0x%x, error=0x%x, refCount=%d\r\n",
 			 cookie, (void *)bp, bp->fid.cell, bp->fid.volume, 
 			 bp->fid.vnode, bp->fid.unique, bp->offset.HighPart, 
 			 bp->offset.LowPart, bp->dataVersion, bp->flags, 
-			 bp->cmFlags, bp->refCount);
+			 bp->cmFlags, bp->error, bp->refCount);
 	WriteFile(outputFile, output, (DWORD)strlen(output), &zilch, NULL);
     }
     StringCbPrintfA(output, sizeof(output), "%s - Done dumping buf_dirtyListp.\r\n", cookie);
