@@ -12,9 +12,7 @@
 #ifndef _OSIFD_H_ENV_
 #define _OSIFD_H_ENV_ 1
 
-#ifndef DJGPP
 #include "dbrpc.h"
-#endif /* !DJGPP */
 #include "osiqueue.h"
 
 struct osi_fd;
@@ -28,12 +26,10 @@ typedef struct osi_fdOps {
 	 */
 	long (*Create)(struct osi_fdType *, struct osi_fd **);
 
-#ifndef DJGPP
 	/* gets info about the object; fields are type specific, and eventually
 	 * self-labelling
 	 */
 	long (*GetInfo)(struct osi_fd *, osi_remGetInfoParms_t *);
-#endif
 
 	/* close an object; frees the storage associated with it */
 	long (*Close)(struct osi_fd *);
@@ -79,22 +75,20 @@ extern osi_fdType_t *osi_RegisterFDType(char *, osi_fdOps_t *, void *);
 
 extern long osi_UnregisterFDType(char *);
 
-extern osi_AddFDFormatInfo(osi_fdType_t *typep, long region, long index,
+extern int osi_AddFDFormatInfo(osi_fdType_t *typep, long region, long index,
 	char *labelp, long format);
 
-extern osi_InitFD(void);
+extern int osi_InitFD(void);
 
 extern osi_fd_t *osi_AllocFD(char *);
 
 extern osi_fd_t *osi_FindFD(long);
 
-extern osi_CloseFD(osi_fd_t *);
+extern int osi_CloseFD(osi_fd_t *);
 
 extern long osi_FDTypeCreate(osi_fdType_t *, osi_fd_t **);
 
-#ifndef DJGPP
 extern long osi_FDTypeGetInfo(osi_fd_t *, osi_remGetInfoParms_t *);
-#endif
 
 extern long osi_FDTypeClose(osi_fd_t *);
 
