@@ -22,8 +22,6 @@
 #include <afsconfig.h>
 #include "afs/param.h"
 
-RCSID
-    ("$Header: /cvs/openafs/src/afs/afs_osi_pag.c,v 1.29.4.15 2009/03/18 13:41:35 shadow Exp $");
 
 #include "afs/sysincludes.h"	/* Standard vendor system headers */
 #include "afsincludes.h"	/* Afs-based standard headers */
@@ -148,7 +146,7 @@ static int afs_pag_sleepcnt = 0;
 static int afs_pag_timewarn = 0;
 
 static int
-afs_pag_sleep(struct AFS_UCRED **acred)
+afs_pag_sleep(AFS_UCRED **acred)
 {
     int rv = 0;
 
@@ -169,7 +167,7 @@ afs_pag_sleep(struct AFS_UCRED **acred)
 }
 
 static int
-afs_pag_wait(struct AFS_UCRED **acred)
+afs_pag_wait(AFS_UCRED **acred)
 {
     if (afs_pag_sleep(acred)) {
 	if (!afs_pag_sleepcnt) {
@@ -192,7 +190,7 @@ afs_pag_wait(struct AFS_UCRED **acred)
 
 int
 #if	defined(AFS_SUN5_ENV)
-afs_setpag(struct AFS_UCRED **credpp)
+afs_setpag(AFS_UCRED **credpp)
 #elif  defined(AFS_OSF_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
 afs_setpag(struct proc *p, void *args, int *retval)
 #else
@@ -201,11 +199,11 @@ afs_setpag(void)
 {
 
 #if     defined(AFS_SUN5_ENV)
-    struct AFS_UCRED **acred = *credpp;
+    AFS_UCRED **acred = *credpp;
 #elif  defined(AFS_OBSD_ENV)
-    struct AFS_UCRED **acred = &p->p_ucred;
+    AFS_UCRED **acred = &p->p_ucred;
 #else
-    struct AFS_UCRED **acred = NULL;
+    AFS_UCRED **acred = NULL;
 #endif
 
     int code = 0;
@@ -250,19 +248,19 @@ afs_setpag(void)
     }
 #elif	defined(AFS_LINUX20_ENV)
     {
-	struct AFS_UCRED *credp = crref();
+	AFS_UCRED *credp = crref();
 	code = AddPag(genpag(), &credp);
 	crfree(credp);
     }
 #elif defined(AFS_DARWIN80_ENV)
     {
-	struct ucred *credp = kauth_cred_proc_ref(p);
+	AFS_UCRED *credp = kauth_cred_proc_ref(p);
 	code = AddPag(p, genpag(), &credp);
-	kauth_cred_rele(credp);
+	crfree(credp);
     }
 #elif defined(AFS_DARWIN_ENV)
     {
-	struct ucred *credp = crdup(p->p_cred->pc_ucred);
+	AFS_UCRED *credp = crdup(p->p_cred->pc_ucred);
 	code = AddPag(p, genpag(), &credp);
 	crfree(credp);
     }
@@ -294,7 +292,7 @@ afs_setpag(void)
  */
 int
 #if	defined(AFS_SUN5_ENV)
-afs_setpag_val(struct AFS_UCRED **credpp, int pagval)
+afs_setpag_val(AFS_UCRED **credpp, int pagval)
 #elif  defined(AFS_OSF_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
 afs_setpag_val(struct proc *p, void *args, int *retval, int pagval)
 #else
@@ -303,11 +301,11 @@ afs_setpag_val(int pagval)
 {
 
 #if     defined(AFS_SUN5_ENV)
-    struct AFS_UCRED **acred = *credp;
+    AFS_UCRED **acred = *credp;
 #elif  defined(AFS_OBSD_ENV)
-    struct AFS_UCRED **acred = &p->p_ucred;
+    AFS_UCRED **acred = &p->p_ucred;
 #else
-    struct AFS_UCRED **acred = NULL;
+    AFS_UCRED **acred = NULL;
 #endif
 
     int code = 0;
@@ -351,7 +349,7 @@ afs_setpag_val(int pagval)
     }
 #elif	defined(AFS_LINUX20_ENV)
     {
-	struct AFS_UCRED *credp = crref();
+	AFS_UCRED *credp = crref();
 	code = AddPag(pagval, &credp);
 	crfree(credp);
     }
@@ -378,10 +376,10 @@ afs_setpag_val(int pagval)
 
 #ifndef AFS_LINUX26_ONEGROUP_ENV
 int
-afs_getpag_val()
+afs_getpag_val(void)
 {
     int pagvalue;
-    struct AFS_UCRED *credp = u.u_cred;
+    AFS_UCRED *credp = u.u_cred;
     gid_t gidset0, gidset1;
 #ifdef AFS_SUN510_ENV
     const gid_t *gids;
@@ -403,13 +401,14 @@ afs_getpag_val()
 /* Note - needs to be available on AIX, others can be static - rework this */
 #if defined(AFS_OSF_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
 int
-AddPag(struct proc *p, afs_int32 aval, struct AFS_UCRED **credpp)
+AddPag(struct proc *p, afs_int32 aval, AFS_UCRED **credpp)
 #else
 int
-AddPag(afs_int32 aval, struct AFS_UCRED **credpp)
+AddPag(afs_int32 aval, AFS_UCRED **credpp)
 #endif
 {
-    afs_int32 newpag, code;
+    afs_int32 code;
+    afs_uint32 newpag;
 
     AFS_STATCNT(AddPag);
 #if defined(AFS_OSF_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
@@ -427,9 +426,11 @@ AddPag(afs_int32 aval, struct AFS_UCRED **credpp)
 
 
 int
-afs_InitReq(register struct vrequest *av, struct AFS_UCRED *acred)
+afs_InitReq(register struct vrequest *av, AFS_UCRED *acred)
 {
+#if defined(AFS_LINUX26_ENV) && !defined(AFS_NONFSTRANS)
     int code;
+#endif
     int i = 0;
 
     AFS_STATCNT(afs_InitReq);
@@ -544,7 +545,7 @@ afs_get_groups_from_pag(afs_uint32 pag, gid_t * g0p, gid_t * g1p)
 
 
 afs_int32
-PagInCred(struct AFS_UCRED *cred)
+PagInCred(AFS_UCRED *cred)
 {
     afs_int32 pag;
 #if !defined(AFS_LINUX26_ONEGROUP_ENV)
@@ -612,7 +613,9 @@ PagInCred(struct AFS_UCRED *cred)
 #else
     pag = (afs_int32) afs_get_pag_from_groups(g0, g1);
 #endif
+#if defined(AFS_SGI_ENV) || defined(AFS_SUN5_ENV) || defined(AFS_DUX40_ENV) || defined(AFS_LINUX20_ENV) || defined(AFS_XBSD_ENV)
 out:
+#endif
 #if defined(AFS_LINUX26_ENV) && defined(LINUX_KEYRING_SUPPORT)
     if (pag == NOPAG && cred->cr_rgid != NFSXLATOR_CRED) {
 	struct key *key;
