@@ -26,7 +26,6 @@ extern void afs_FreeAllAxs(struct axscache **headp);
 /* afs_buffer.c */
 extern void DInit(int abuffers);
 extern void *DRead(register struct dcache * fid, register int page);
-extern void DRelease(register struct buffer *bp, int flag);
 extern int DVOffset(register void *ap);
 extern void DZap(struct dcache * fid);
 extern void DFlush(void);
@@ -46,6 +45,11 @@ extern void shutdown_afstest(void);
 extern void afs_shutdown_BKG(void);
 extern int afs_syscall_call(long parm, long parm2, long parm3,
 			    long parm4, long parm5, long parm6);
+#if defined(AFS_DARWIN100_ENV)
+extern int afs_syscall64_call(user_addr_t parm, user_addr_t parm2,
+			      user_addr_t parm3, user_addr_t parm4,
+			      user_addr_t parm5, user_addr_t parm6);
+#endif
 
 
 /* afs_callback.c */
@@ -206,9 +210,10 @@ extern void afs_Daemon(void);
 extern struct brequest *afs_BQueue(register short aopcode,
 				   register struct vcache *avc,
 				   afs_int32 dontwait, afs_int32 ause,
-				   struct AFS_UCRED *acred,
+				   AFS_UCRED *acred,
 				   afs_size_t asparm0, afs_size_t asparm1,
 				   void *apparm0);
+extern void afs_SetCheckServerNATmode(int isnat);
 extern void afs_CheckServerDaemon(void);
 extern int afs_CheckRootVolume(void);
 extern void afs_BRelease(register struct brequest *ab);
@@ -260,7 +265,7 @@ extern int afs_HashOutDCache(struct dcache *adc, int zap);
 extern int afs_MaybeFreeDiscardedDCache(void);
 extern int afs_RefDCache(struct dcache *adc);
 extern void afs_TryToSmush(register struct vcache *avc,
-			   struct AFS_UCRED *acred, int sync);
+			   AFS_UCRED *acred, int sync);
 extern void updateV2DC(int lockVc, struct vcache *v, struct dcache *d,
 		       int src);
 extern void afs_WriteThroughDSlots(void);
@@ -300,9 +305,9 @@ extern int afs_DynrootNewVnode(struct vcache *avc,
 extern int afs_InitDynroot(void);
 extern int afs_SetDynrootEnable(int enable);
 extern int afs_GetDynrootEnable(void);
-extern int afs_DynrootVOPRemove(struct vcache *avc, struct AFS_UCRED *acred,
+extern int afs_DynrootVOPRemove(struct vcache *avc, AFS_UCRED *acred,
 				char *aname);
-extern int afs_DynrootVOPSymlink(struct vcache *avc, struct AFS_UCRED *acred,
+extern int afs_DynrootVOPSymlink(struct vcache *avc, AFS_UCRED *acred,
 				 char *aname, char *atargetName);
 
 /* afs_error.c */
@@ -319,6 +324,17 @@ extern struct afs_exporter *root_exported;
 extern struct afs_exporter *exporter_find(int type);
 extern void shutdown_exporter(void);
 
+/* afs_fetchstore.c */
+extern int afs_UFSCacheFetchProc(struct rx_call *, struct osi_file *,
+                                 afs_size_t, struct dcache *,
+                                 struct vcache *, afs_size_t *,
+                                 afs_size_t *, afs_int32);
+
+extern int afs_UFSCacheStoreProc(struct rx_call *, struct osi_file *,
+                                 afs_int32, struct vcache *,
+                                 int *, afs_size_t *,
+                                 afs_size_t *);
+
 /* afs_icl.c */
 extern struct afs_icl_set *afs_icl_allSets;
 extern int afs_icl_InitLogs(void);
@@ -394,7 +410,10 @@ extern void afs_icl_AppendRecord(register struct afs_icl_log *logp,
 				 long p2, long p3, long p4);
 extern int Afscall_icl(long opcode, long p1, long p2, long p3, long p4,
 		       long *retval);
-
+#ifdef AFS_DARWIN100_ENV
+extern int Afscall64_icl(int opcode, user_addr_t p1, user_addr_t p2,
+		       user_addr_t p3, user_addr_t p4, int *retval);
+#endif
 
 /* afs_init.c */
 extern struct cm_initparams cm_initParams;
@@ -463,6 +482,17 @@ extern void afs_MarinerLog(register char *astring,
 			   register struct vcache *avc);
 extern void shutdown_mariner(void);
 
+/* afs_fetchstore.c */
+extern int afs_CacheStoreVCache(struct dcache **dcList, struct vcache *avc,
+				struct vrequest *areq,
+				int sync, unsigned int minj,
+				unsigned int high, unsigned int moredata,
+				afs_hyper_t *anewDV,
+                                 afs_size_t *amaxStoredLength);
+extern int afs_CacheFetchProc(struct afs_conn *tc, struct osi_file *fP,
+				afs_size_t abase, struct dcache *adc,
+				struct vcache *avc, afs_int32 size,
+				struct afs_FetchOutput *tsmall);
 
 /* afs_memcache.c */
 extern int afs_InitMemCache(int blkCount, int blkSize, int flags);
@@ -480,18 +510,6 @@ extern int afs_MemWritevBlk(register struct memCacheEntry *mceP, int offset,
 extern int afs_MemWriteUIO(afs_dcache_id_t *ainode, struct uio *uioP);
 extern int afs_MemCacheTruncate(register struct osi_file *fP,
 				int size);
-extern int afs_MemCacheStoreProc(register struct rx_call *acall,
-				 register struct osi_file *fP,
-				 register afs_int32 alen, struct vcache *avc,
-				 int *shouldWake, afs_size_t * abytesToXferP,
-				 afs_size_t * abytesXferredP);
-extern int afs_MemCacheFetchProc(register struct rx_call *acall,
-				 register struct osi_file *fP,
-				 afs_size_t abase, struct dcache *adc,
-				 struct vcache *avc,
-				 afs_size_t * abytesToXferP,
-				 afs_size_t * abytesXferredP,
-				 afs_int32 lengthFound);
 extern void shutdown_memcache(void);
 
 
@@ -500,7 +518,7 @@ extern struct afs_exporter *afs_nfsexported;
 extern struct afs_exporter *afs_nfsexporter;
 extern void afs_nfsclient_init(void);
 extern int afs_nfsclient_reqhandler(struct afs_exporter *exporter,
-				    struct AFS_UCRED **cred,
+				    AFS_UCRED **cred,
 				    afs_int32 host, afs_int32 *pagparam,
 				    struct afs_exporter **outexporter);
 extern void shutdown_nfsclnt(void);
@@ -523,7 +541,7 @@ extern void shutdown_osinet(void);
 extern int afs_osi_suser(void *credp);
 extern void afs_osi_TraverseProcTable(void);
 #if defined(KERNEL) && !defined(UKERNEL) && defined(AFS_PROC)
-extern const struct AFS_UCRED *afs_osi_proc2cred(AFS_PROC * pr);
+extern const AFS_UCRED *afs_osi_proc2cred(AFS_PROC * pr);
 #endif
 
 /* afs_osi_alloc.c */
@@ -549,7 +567,7 @@ extern void shutdown_osinet(void);
 
 /* afs_osi_pag.c */
 #if defined(AFS_SUN5_ENV)
-extern int afs_setpag(struct AFS_UCRED **credpp);
+extern int afs_setpag(AFS_UCRED **credpp);
 #elif  defined(AFS_OSF_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
 extern int afs_setpag(struct proc *p, void *args, int *retval);
 #else
@@ -559,12 +577,12 @@ extern int afs_setpag(void);
 extern afs_uint32 genpag(void);
 extern afs_uint32 getpag(void);
 #if defined(AFS_OSF_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
-extern int AddPag(struct proc *p, afs_int32 aval, struct AFS_UCRED **credpp);
+extern int AddPag(struct proc *p, afs_int32 aval, AFS_UCRED **credpp);
 #else
-extern int AddPag(afs_int32 aval, struct AFS_UCRED **credpp);
+extern int AddPag(afs_int32 aval, AFS_UCRED **credpp);
 #endif
-extern int afs_InitReq(register struct vrequest *av, struct AFS_UCRED *acred);
-#if defined(UKERNEL) && defined(AFS_WEB_ENHANCEMENTS)
+extern int afs_InitReq(register struct vrequest *av, AFS_UCRED *acred);
+#if defined(UKERNEL)
 extern afs_uint32 afs_get_pag_from_groups(gid_t g0a, gid_t g1a);
 #else
 #ifdef AFS_LINUX26_ONEGROUP_ENV
@@ -572,7 +590,7 @@ extern afs_uint32 afs_get_pag_from_groups(struct group_info *gi);
 #endif
 #endif
 extern void afs_get_groups_from_pag(afs_uint32 pag, gid_t * g0p, gid_t * g1p);
-extern afs_int32 PagInCred(struct AFS_UCRED *cred);
+extern afs_int32 PagInCred(AFS_UCRED *cred);
 
 /* afs_osi_uio.c */
 extern int afsio_copy(struct uio *ainuio, struct uio *aoutuio,
@@ -583,11 +601,11 @@ extern int afsio_skip(struct uio *auio, afs_int32 asize);
 /* afs_osi_vm.c */
 extern int osi_Active(register struct vcache *avc);
 extern void osi_FlushPages(register struct vcache *avc,
-			   struct AFS_UCRED *credp);
+			   AFS_UCRED *credp);
 extern void osi_FlushText_really(register struct vcache *vp);
 extern int osi_VMDirty_p(struct vcache *avc);
 #ifndef UKERNEL
-extern void osi_ReleaseVM(struct vcache *avc, struct AFS_UCRED *acred);
+extern void osi_ReleaseVM(struct vcache *avc, AFS_UCRED *acred);
 #endif
 
 
@@ -634,10 +652,10 @@ extern int afs_osi_SleepSig(void *event);
 /* ARCH/osi_inode.c */
 #ifdef AFS_SUN5_ENV
 extern int afs_syscall_icreate(dev_t, long, long, long, long, long, 
-		               rval_t *, struct AFS_UCRED *);
-extern int afs_syscall_iopen(dev_t, int, int, rval_t *, struct AFS_UCRED *);
+		               rval_t *, AFS_UCRED *);
+extern int afs_syscall_iopen(dev_t, int, int, rval_t *, AFS_UCRED *);
 extern int afs_syscall_iincdec(dev_t, int, int, int, rval_t *, 
-			       struct AFS_UCRED *);
+			       AFS_UCRED *);
 #elif defined(AFS_SGI65_ENV)
 extern int afs_syscall_icreate(afs_uint32, afs_uint32, afs_uint32, afs_uint32, afs_uint32, afs_uint32, rval_t *);
 extern int afs_syscall_iopen(int, ino_t, int, rval_t *);
@@ -673,22 +691,27 @@ extern void shutdown_osifile(void);
 
 
 /* ARCH/osi_groups.c */
-#if defined AFS_XBSD_ENV
-#if !defined(AFS_DFBSD_ENV) || !defined(UKERNEL)
+#if defined(UKERNEL)
+extern int usr_setpag(struct usr_ucred **cred, afs_uint32 pagvalue,
+		      afs_uint32 * newpag, int change_parent);
+#else
+# if defined AFS_XBSD_ENV
+#  if !defined(AFS_DFBSD_ENV)
 extern int setpag(struct proc *proc, struct ucred **cred, afs_uint32 pagvalue,
 		  afs_uint32 * newpag, int change_parent);
-#endif
+#  endif
+# endif
 #endif
 
 
 /* ARCH/osi_vm.c */
 extern int osi_VM_FlushVCache(struct vcache *avc, int *slept);
 extern void osi_VM_StoreAllSegments(struct vcache *avc);
-extern void osi_VM_TryToSmush(struct vcache *avc, struct AFS_UCRED *acred,
+extern void osi_VM_TryToSmush(struct vcache *avc, AFS_UCRED *acred,
 			      int sync);
-extern void osi_VM_FlushPages(struct vcache *avc, struct AFS_UCRED *credp);
+extern void osi_VM_FlushPages(struct vcache *avc, AFS_UCRED *credp);
 extern void osi_VM_Truncate(struct vcache *avc, int alen,
-			    struct AFS_UCRED *acred);
+			    AFS_UCRED *acred);
 extern void osi_VM_TryReclaim(struct vcache *avc, int *slept);
 extern void osi_VM_NukePages(struct vnode *vp, off_t offset, off_t size);
 extern int osi_VM_Setup(struct vcache *avc, int force);
@@ -696,7 +719,7 @@ extern int osi_VM_Setup(struct vcache *avc, int force);
 #ifdef AFS_SUN5_ENV
 extern int osi_VM_GetDownD(struct vcache *avc, struct dcache *adc);
 extern void osi_VM_PreTruncate(struct vcache *avc, int alen,
-			       struct AFS_UCRED *acred);
+			       AFS_UCRED *acred);
 #endif
 
 
@@ -713,7 +736,7 @@ extern int numvnodes;		/* number vnodes in use now */
 extern struct vfs_ubcops afs_ubcops;
 #endif
 #endif
-extern int afs_inactive(struct vcache *avc, struct AFS_UCRED *acred);
+extern int afs_inactive(struct vcache *avc, AFS_UCRED *acred);
 
 /* afs_osifile.c */
 
@@ -733,6 +756,12 @@ extern void vcache2inode(struct vcache *avc);
 extern void vcache2fakeinode(struct vcache *rootvp, struct vcache *mpvp);
 #endif
 
+#ifdef UKERNEL
+extern int afs_mount(struct vfs *afsp, char *path, void *data);
+extern int afs_root(OSI_VFS_DECL(afsp), struct vnode **avpp);
+extern int afs_unmount(struct vfs *afsp);
+#endif
+
 /* afs_pag_call.c */
 extern afs_int32 afs_nfs_server_addr;
 extern void afspag_Init(afs_int32 nfs_server_addr);
@@ -742,11 +771,11 @@ extern void afspag_Shutdown(void);
 extern afs_rwlock_t afs_xpagcell;
 extern afs_rwlock_t afs_xpagsys;
 extern int afspag_PUnlog(char *ain, afs_int32 ainSize,
-			 struct AFS_UCRED **acred);
+			 AFS_UCRED **acred);
 extern int afspag_PSetTokens(char *ain, afs_int32 ainSize,
-			     struct AFS_UCRED **acred);
+			     AFS_UCRED **acred);
 extern int afspag_PSetSysName(char *ain, afs_int32 ainSize,
-                              struct AFS_UCRED **acred);
+                              AFS_UCRED **acred);
 
 /* afs_pioctl.c */
 extern struct VenusFid afs_rootFid;
@@ -754,12 +783,17 @@ extern afs_int32 afs_waitForever;
 extern short afs_waitForeverCount;
 extern afs_int32 afs_showflags;
 extern int afs_defaultAsynchrony;
+#if defined(AFS_DARWIN100_ENV)
+extern int afs_syscall64_pioctl(user_addr_t path, unsigned int com,
+				user_addr_t cmarg, int follow, \
+				AFS_UCRED *credp);
+#endif
 #ifdef AFS_SUN5_ENV
 extern int afs_syscall_pioctl(char *path, unsigned int com, caddr_t cmarg, 
-			      int follow, rval_t *rvp, struct AFS_UCRED *credp);
+			      int follow, rval_t *rvp, AFS_UCRED *credp);
 #elif defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
 extern int afs_syscall_pioctl(char *path, unsigned int com, caddr_t cmarg, 
-			      int follow, struct AFS_UCRED *credp);
+			      int follow, AFS_UCRED *credp);
 #else
 extern int afs_syscall_pioctl(char *path, unsigned int com, caddr_t cmarg,
 			      int follow);
@@ -777,7 +811,7 @@ extern int afs_ExtendSegments(struct vcache *avc,
 			      afs_size_t alen, struct vrequest *areq);
 extern int afs_TruncateAllSegments(register struct vcache *avc,
 				   afs_size_t alen, struct vrequest *areq,
-				   struct AFS_UCRED *acred);
+				   AFS_UCRED *acred);
 
 /* afs_server.c */
 extern afs_rwlock_t afs_xsrvAddr;
@@ -848,8 +882,14 @@ extern void afs_AddToMean(struct afs_MeanStats *oldMean, afs_int32 newValue);
 #endif
 
 /* afs_syscall.c */
+#ifdef AFS_DARWIN100_ENV
+extern int copyin_afs_ioctl(user_addr_t cmarg, struct afs_ioctl *dst);
+#else
 extern int copyin_afs_ioctl(caddr_t cmarg, struct afs_ioctl *dst);
-
+#endif
+#ifdef UKERNEL
+extern int Afs_syscall(void);
+#endif
 
 /* UKERNEL/afs_usrops.c */
 #ifdef UKERNEL
@@ -857,11 +897,16 @@ extern void uafs_Shutdown(void);
 extern void osi_ReleaseVM(struct vcache *avc, int len,
 			  struct usr_ucred *credp);
 extern int osi_GetTime(struct timeval *tv);
+extern int iodone(struct usr_buf *bp);
+extern int usr_ioctl(void);
+extern int lookupname(char *fnamep, int segflg, int followlink,
+		      struct usr_vnode **compvpp);
+extern int usr_uiomove(char *kbuf, int n, int rw, struct usr_uio *uio);
+extern int afs_osi_VOP_RDWR(struct usr_vnode *vnodeP, struct usr_uio *uioP,
+		            int rw, int flags, struct usr_ucred *credP);
+
 #endif
 
-
-
-
 /* afs_user.c */
 extern afs_rwlock_t afs_xuser;
 extern struct unixuser *afs_users[NUSERS];
@@ -907,22 +952,21 @@ extern void print_internet_address(char *preamble, struct srvAddr *sa,
 				   char *postamble, int flag);
 extern afs_int32 afs_data_pointer_to_int32(const void *p);
 
-#if 0				/* problems - need to change to varargs, right now is incorrect usage
-				 * throughout code */
-extern void afs_warn(char *a, long b, long c, long d, long e, long f, long g,
-		     long h, long i, long j);
-extern void afs_warnuser(char *a, long b, long c, long d, long e, long f,
-			 long g, long h, long i, long j);
-#else
-extern void afs_warn();
-extern void afs_warnuser();
-#endif
 extern void afs_CheckLocks(void);
 extern int afs_badop(void);
 extern int afs_noop(void);
 extern afs_int32 afs_data_pointer_to_int32(const void *p);
 
+/* afs_warn.c */
 
+#ifdef AFS_AIX_ENV
+/* AIX doesn't have usable va_args support in its kernel */
+extern void afs_warn();
+extern void afs_warnuser();
+#else
+extern void afs_warn(char *fmt, ...);
+extern void afs_warnuser(char *fmt, ...);
+#endif
 
 /* afs_vcache.c */
 extern int afs_ShakeLooseVCaches(afs_int32 anumber);
@@ -952,7 +996,7 @@ extern afs_int32 afs_FetchStatus(struct vcache *avc, struct VenusFid *afid,
 				 struct AFSFetchStatus *Outsp);
 
 extern afs_int32 afs_FlushVCBs(afs_int32 lockit);
-extern void afs_InactiveVCache(struct vcache *avc, struct AFS_UCRED *acred);
+extern void afs_InactiveVCache(struct vcache *avc, AFS_UCRED *acred);
 extern struct vcache *afs_LookupVCache(struct VenusFid *afid,
 				       struct vrequest *areq,
 				       afs_int32 * cached, struct vcache *adp,
@@ -986,7 +1030,7 @@ extern int afs_RemoteLookup(register struct VenusFid *afid,
 			    struct AFSCallBack *CallBackp,
 			    struct server **serverp,
 			    struct AFSVolSync *tsyncp);
-extern void afs_ResetVCache(struct vcache *, struct AFS_UCRED *);
+extern void afs_ResetVCache(struct vcache *, AFS_UCRED *);
 extern afs_int32 afs_NFSFindVCache(struct vcache **avcp,
 				   struct VenusFid *afid);
 extern void afs_vcacheInit(int astatSize);
@@ -1002,33 +1046,33 @@ extern int afs_AccessOK(struct vcache *avc, afs_int32 arights,
 			struct vrequest *areq, afs_int32 check_mode_bits);
 #if defined(AFS_SUN5_ENV) || (defined(AFS_SGI_ENV) && !defined(AFS_SGI65_ENV))
 extern int afs_access(OSI_VC_DECL(avc), register afs_int32 amode, int flags,
-		      struct AFS_UCRED *acred);
+		      AFS_UCRED *acred);
 #else
 extern int afs_access(OSI_VC_DECL(avc), register afs_int32 amode,
-		      struct AFS_UCRED *acred);
+		      AFS_UCRED *acred);
 #endif
 extern int afs_getRights(OSI_VC_DECL(avc), register afs_int32 arights,
-			 struct AFS_UCRED *acred);
+			 AFS_UCRED *acred);
 
 /* VNOPS/afs_vnop_attrs.c */
 extern int afs_CopyOutAttrs(register struct vcache *avc,
 			    register struct vattr *attrs);
 #if     defined(AFS_SUN5_ENV) || defined(AFS_SGI_ENV)
 extern int afs_getattr(OSI_VC_DECL(avc), struct vattr *attrs, int flags,
-		       struct AFS_UCRED *acred);
+		       AFS_UCRED *acred);
 #else
 extern int afs_getattr(OSI_VC_DECL(avc), struct vattr *attrs,
-		       struct AFS_UCRED *acred);
+		       AFS_UCRED *acred);
 #endif
 extern int afs_VAttrToAS(register struct vcache *avc,
 			 register struct vattr *av,
 			 register struct AFSStoreStatus *as);
 #if defined(AFS_SUN5_ENV) || defined(AFS_SGI_ENV)
 extern int afs_setattr(OSI_VC_DECL(avc), register struct vattr *attrs,
-		       int flags, struct AFS_UCRED *acred);
+		       int flags, AFS_UCRED *acred);
 #else
 extern int afs_setattr(OSI_VC_DECL(avc), register struct vattr *attrs,
-		       struct AFS_UCRED *acred);
+		       AFS_UCRED *acred);
 #endif
 
 /* VNOPS/afs_vnop_create.c */
@@ -1038,11 +1082,11 @@ extern int afs_create(struct nameidata *ndp, struct vattr *attrs);
 #ifdef AFS_SGI64_ENV
 extern int afs_create(OSI_VC_DECL(adp), char *aname, struct vattr *attrs,
 		      int flags, int amode, struct vcache **avcp,
-		      struct AFS_UCRED *acred);
+		      AFS_UCRED *acred);
 #else /* AFS_SGI64_ENV */
 extern int afs_create(OSI_VC_DECL(adp), char *aname, struct vattr *attrs,
 		      enum vcexcl aexcl, int amode, struct vcache **avcp,
-		      struct AFS_UCRED *acred);
+		      AFS_UCRED *acred);
 #endif /* AFS_SGI64_ENV */
 #endif /* AFS_OSF_ENV */
 extern int afs_LocalHero(register struct vcache *avc,
@@ -1052,12 +1096,12 @@ extern int afs_LocalHero(register struct vcache *avc,
 /* VNOPS/afs_vnop_dirops.c */
 
 extern int afs_mkdir(OSI_VC_DECL(adp), char *aname, struct vattr *attrs, 
-		     register struct vcache **avcp, struct AFS_UCRED *acred);
+		     register struct vcache **avcp, AFS_UCRED *acred);
 #if defined(AFS_SUN5_ENV) || defined(AFS_SGI_ENV)
 extern int afs_rmdir(OSI_VC_DECL(adp), char *aname, struct vnode *cdirp, 
-		     struct AFS_UCRED *acred);
+		     AFS_UCRED *acred);
 #else
-extern int afs_rmdir(OSI_VC_DECL(adp), char *aname, struct AFS_UCRED *acred);
+extern int afs_rmdir(OSI_VC_DECL(adp), char *aname, AFS_UCRED *acred);
 #endif
 
 struct fid;
@@ -1082,22 +1126,22 @@ extern int HandleFlock(register struct vcache *avc, int acom,
 
 #ifdef AFS_OSF_ENV
 extern int afs_lockctl(struct vcache * avc, struct eflock * af, int flag,
-		       struct AFS_UCRED * acred, pid_t clid, off_t offset);
+		       AFS_UCRED * acred, pid_t clid, off_t offset);
 #elif defined(AFS_SGI_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
 extern int afs_lockctl(struct vcache * avc, struct AFS_FLOCK * af, int acmd,
-		       struct AFS_UCRED * acred, pid_t clid);
+		       AFS_UCRED * acred, pid_t clid);
 #else
 extern int afs_lockctl(struct vcache * avc, struct AFS_FLOCK * af, int acmd,
-		       struct AFS_UCRED * acred);
+		       AFS_UCRED * acred);
 #endif
 
 /* VNOPS/afs_vnop_link.c */
 #if defined(AFS_SUN5_ENV) || defined(AFS_SGI_ENV)
 extern int afs_link(OSI_VC_DECL(adp), struct vcache *avc, char *aname, 
-		    struct AFS_UCRED *acred);
+		    AFS_UCRED *acred);
 #else
 extern int afs_link(struct vcache *avc, OSI_VC_DECL(adp), char *aname, 
-		    struct AFS_UCRED *acred);
+		    AFS_UCRED *acred);
 #endif
 
 /* VNOPS/afs_vnop_lookup.c */
@@ -1121,26 +1165,26 @@ extern int afs_DoBulkStat(struct vcache *adp, long dirCookie,
 			  struct vrequest *areqp);
 #ifdef AFS_OSF_ENV
 extern int afs_lookup(OSI_VC_DECL(adp), char *aname, struct vcache **avcp, 
-		      struct AFS_UCRED *acred, int opflag, int wantparent);
+		      AFS_UCRED *acred, int opflag, int wantparent);
 #elif defined(AFS_SUN5_ENV) || defined(AFS_SGI_ENV)
 extern int afs_lookup(OSI_VC_DECL(adp), char *aname, struct vcache **avcp, 
 		      struct pathname *pnp, int flags, struct vnode *rdir, 
-		      struct AFS_UCRED *acred);
+		      AFS_UCRED *acred);
 #elif defined(UKERNEL)
 extern int afs_lookup(OSI_VC_DECL(adp), char *aname, struct vcache **avcp, 
-		      struct AFS_UCRED *acred, int flags);
+		      AFS_UCRED *acred, int flags);
 #else
 extern int afs_lookup(OSI_VC_DECL(adp), char *aname, struct vcache **avcp, 
-		      struct AFS_UCRED *acred);
+		      AFS_UCRED *acred);
 #endif
 	
 /* VNOPS/afs_vnop_open.c */
 #ifdef AFS_SGI64_ENV
 extern int afs_open(bhv_desc_t * bhv, struct vcache **avcp, afs_int32 aflags,
-		    struct AFS_UCRED *acred);
+		    AFS_UCRED *acred);
 #else
 extern int afs_open(struct vcache **avcp, afs_int32 aflags,
-		    struct AFS_UCRED *acred);
+		    AFS_UCRED *acred);
 #endif
 
 
@@ -1149,52 +1193,52 @@ extern afs_int32 maxIHint;
 extern afs_int32 nihints;
 extern afs_int32 usedihint;
 extern int afs_MemRead(register struct vcache *avc, struct uio *auio,
-		       struct AFS_UCRED *acred, daddr_t albn,
+		       AFS_UCRED *acred, daddr_t albn,
 		       struct buf **abpp, int noLock);
 extern int afs_UFSRead(register struct vcache *avc, struct uio *auio,
-		       struct AFS_UCRED *acred, daddr_t albn,
+		       AFS_UCRED *acred, daddr_t albn,
 		       struct buf **abpp, int noLock);
 extern void afs_PrefetchChunk(struct vcache *avc, struct dcache *adc,
-			      struct AFS_UCRED *acred, struct vrequest *areq);
+			      AFS_UCRED *acred, struct vrequest *areq);
 
 
 /* VNOPS/afs_vnop_readdir.c */
 extern int afs_rd_stash_i;
 #if defined(AFS_SUN5_ENV) || defined(AFS_SGI_ENV) || defined(AFS_OSF_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
 extern int afs_readdir(OSI_VC_DECL(avc), struct uio *auio, 
-		       struct AFS_UCRED *acred, int *eofp);
+		       AFS_UCRED *acred, int *eofp);
 #elif defined(AFS_HPUX100_ENV)
 extern int afs_readdir2(OSI_VC_DECL(avc), struct uio *auio, 
-		        struct AFS_UCRED *acred);
+		        AFS_UCRED *acred);
 #else
 extern int afs_readdir(OSI_VC_DECL(avc), struct uio *auio, 
-		       struct AFS_UCRED *acred);
+		       AFS_UCRED *acred);
 #endif
 
 /* VNOPS/afs_vnop_remove.c */
 extern int afsremove(register struct vcache *adp, register struct dcache *tdc,
 		     register struct vcache *tvc, char *aname,
-		     struct AFS_UCRED *acred, struct vrequest *treqp);
+		     AFS_UCRED *acred, struct vrequest *treqp);
 extern int afs_remunlink(register struct vcache *avc, register int doit);
-extern int afs_remove(OSI_VC_DECL(adp), char *aname, struct AFS_UCRED *acred);
+extern int afs_remove(OSI_VC_DECL(adp), char *aname, AFS_UCRED *acred);
 extern char *afs_newname(void);
 
 /* VNOPS/afs_vnop_rename.c */
 extern int afsrename(struct vcache *aodp, char *aname1, struct vcache *andp,
-		     char *aname2, struct AFS_UCRED *acred,
+		     char *aname2, AFS_UCRED *acred,
 		     struct vrequest *areq);
 #ifdef AFS_SGI_ENV
 extern int afs_rename(OSI_VC_DECL(aodp), char *aname1, struct vcache *andp, 
 		      char *aname2, struct pathname *npnp, 
-		      struct AFS_UCRED *acred);
+		      AFS_UCRED *acred);
 #else
 extern int afs_rename(OSI_VC_DECL(aodp), char *aname1, struct vcache *andp, 
-		      char *aname2, struct AFS_UCRED *acred);
+		      char *aname2, AFS_UCRED *acred);
 #endif
 	
 /* VNOPS/afs_vnop_strategy.c */
 #if defined(AFS_SUN5_ENV) || defined(AFS_OSF_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
-extern int afs_ustrategy(register struct buf *adp, struct AFS_UCRED *credp);
+extern int afs_ustrategy(register struct buf *adp, AFS_UCRED *credp);
 #else
 extern int afs_ustrategy(register struct buf *adp);
 #endif
@@ -1206,50 +1250,50 @@ extern int afs_UFSHandleLink(register struct vcache *avc,
 			     struct vrequest *areq);
 extern int afs_symlink(OSI_VC_DECL(adp), char *aname, 
 		       struct vattr *attrs, char *atargetName, 
-		       struct AFS_UCRED *acred);
+		       AFS_UCRED *acred);
 extern int afs_readlink(OSI_VC_DECL(avc), struct uio *auio,
-			struct AFS_UCRED *acred);
+			AFS_UCRED *acred);
 
 /* VNOPS/afs_vnop_write.c */
 extern int afs_MemWrite(register struct vcache *avc, struct uio *auio,
-			int aio, struct AFS_UCRED *acred, int noLock);
+			int aio, AFS_UCRED *acred, int noLock);
 extern int afs_StoreOnLastReference(register struct vcache *avc,
 				    register struct vrequest *treq);
 extern int afs_UFSWrite(register struct vcache *avc, struct uio *auio,
-			int aio, struct AFS_UCRED *acred, int noLock);
+			int aio, AFS_UCRED *acred, int noLock);
 extern int afs_DoPartialWrite(register struct vcache *avc,
 			      struct vrequest *areq);
 extern int afs_closex(register struct file *afd);
 
 #ifdef AFS_SGI65_ENV
 extern int afs_close(OSI_VC_DECL(avc), afs_int32 aflags, 
-		     lastclose_t lastclose, struct AFS_UCRED *acred);
+		     lastclose_t lastclose, AFS_UCRED *acred);
 #elif defined(AFS_SGI64_ENV)
 extern int afs_close(OSI_VC_DECL(avc), afs_int32 aflags, 
 		     lastclose_t lastclose, off_t offset, 
-		     struct AFS_UCRED *acred, struct flid *flp);
+		     AFS_UCRED *acred, struct flid *flp);
 #elif defined(AFS_SGI_ENV)
 extern int afs_close(OSI_VC_DECL(avc), afs_int32 aflags, 
 		     lastclose_t lastclose, off_t offset,
-		     struct AFS_UCRED *acred);
+		     AFS_UCRED *acred);
 #elif defined(AFS_SUN5_ENV)
 extern int afs_close(OSI_VC_DECL(avc), afs_int32 aflags, int count, 
-		     offset_t offset, struct AFS_UCRED *acred);
+		     offset_t offset, AFS_UCRED *acred);
 #else
 extern int afs_close(OSI_VC_DECL(avc), afs_int32 aflags,  
-		     struct AFS_UCRED *acred);
+		     AFS_UCRED *acred);
 #endif
 
 #ifdef AFS_OSF_ENV
-extern int afs_fsync(OSI_VC_DECL(avc), int fflags, struct AFS_UCRED *acred, 
+extern int afs_fsync(OSI_VC_DECL(avc), int fflags, AFS_UCRED *acred, 
 		     int waitfor);
 #elif defined(AFS_SGI65_ENV)
-extern int afs_fsync(OSI_VC_DECL(avc), int flags, struct AFS_UCRED *acred, 
+extern int afs_fsync(OSI_VC_DECL(avc), int flags, AFS_UCRED *acred, 
 		     off_t start, off_t stop);
 #elif defined(AFS_SGI_ENV) || defined(AFS_SUN53_ENV)
-extern int afs_fsync(OSI_VC_DECL(avc), int flag, struct AFS_UCRED *acred);
+extern int afs_fsync(OSI_VC_DECL(avc), int flag, AFS_UCRED *acred);
 #else
-extern int afs_fsync(OSI_VC_DECL(avc), struct AFS_UCRED *acred);
+extern int afs_fsync(OSI_VC_DECL(avc), AFS_UCRED *acred);
 #endif
 		
 
@@ -1294,15 +1338,6 @@ extern void afs_ntohuuid(afsUUID * uuidp);
 extern afs_int32 afs_uuid_create(afsUUID * uuid);
 extern u_short afs_uuid_hash(afsUUID * uuid);
 
-
-/* MISC PROTOTYPES - THESE SHOULD NOT BE HERE */
-/* MOVE THEM TO APPROPRIATE LOCATIONS */
-extern afs_int32 RXAFSCB_ExecuteRequest(struct rx_call *acall);
-extern afs_int32 RXSTATS_ExecuteRequest(struct rx_call *acall);
-extern afs_int32 PAGCB_ExecuteRequest(struct rx_call *acall);
-
-
-
 #if defined(AFS_SUN5_ENV) || defined(AFS_LINUX20_ENV) || defined(AFS_AIX_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV) || defined(AFS_HPUX_ENV) || defined(AFS_SGI62_ENV) || defined(AFS_OSF_ENV)
 #include "osi_prototypes.h"
 #endif
