@@ -1,5 +1,5 @@
 /* 
- * $Id: aklog_main.c,v 1.12.2.20 2009/03/15 18:02:41 shadow Exp $
+ * $Id$
  *
  * Copyright 1990,1991 by the Massachusetts Institute of Technology
  * For distribution and copying rights, see the file "mit-copyright.h"
@@ -35,8 +35,7 @@
  */
 
 #include <afsconfig.h>
-RCSID
-     ("$Header: /cvs/openafs/src/aklog/aklog_main.c,v 1.12.2.20 2009/03/15 18:02:41 shadow Exp $");
+
 #include <stdio.h>
 #include <string.h>
 #include <ctype.h>
@@ -74,6 +73,10 @@ RCSID
 #ifdef AFS_SUN5_ENV
 #include <sys/ioccom.h>
 #endif
+
+/* Prevent inclusion of des.h to avoid conflicts with des types */
+#define NO_DES_H_INCLUDE
+
 #include <afs/auth.h>
 #include <afs/cellconfig.h>
 #include <afs/vice.h>
@@ -324,17 +327,6 @@ static char *copy_cellinfo(cellinfo_t *cellinfo)
 }
 
 
-static char *copy_string(char *string)    
-{
-    char *new_string;
-
-    if ((new_string = (char *)calloc(strlen(string) + 1, sizeof(char))))
-	(void) strcpy(new_string, string);
-
-    return (new_string);
-}
-
-
 static int get_cellconfig(char *cell, struct afsconf_cell *cellconfig, char *local_cell, char *linkedcell)
 {
     int status = AKLOG_SUCCESS;
@@ -636,9 +628,11 @@ static int auth_to_cell(krb5_context context, char *cell, char *realm)
 	 */
 
 	if (! do524) {
-	    char *p;
 	    char k4name[ANAME_SZ], k4inst[INST_SZ], k4realm[REALM_SZ];
+#ifdef HAVE_NO_KRB5_524
+	    char *p;
 	    int len;
+#endif
 
 	    if (dflag)
 	    	printf("Using Kerberos V5 ticket natively\n");
@@ -1363,8 +1357,8 @@ void aklog(int argc, char *argv[])
 	else if (pmode) {
 	    /* Add this path to list of paths */
 	    if ((cur_node = ll_add_node(&paths, ll_tail))) {
-		char *new_path; 
-		if ((new_path = copy_string(path)))
+		char *new_path;
+		if ((new_path = strdup(path)))
 		    ll_add_data(cur_node, new_path);
 		else {
 		    fprintf(stderr, "%s: failure copying path name.\n",
