@@ -22,13 +22,12 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/bozo/bos_util.c,v 1.4.14.2 2009/03/16 13:20:06 shadow Exp $");
 
 #include <sys/types.h>
 #include <netinet/in.h>
 #include <netdb.h>
 #include <string.h>
+#include <stdio.h>
 
 #include <afs/stds.h>
 #include <afs/afsutil.h>
@@ -125,7 +124,7 @@ main(int argc, char **argv)
 	    printf("\nInput key mismatch\n");
 	    exit(1);
 	}
-	des_string_to_key(buf, &tkey);
+	des_string_to_key(buf, ktc_to_cblockptr(&tkey));
 	code = afsconf_AddKey(tdir, kvno, &tkey, 0);
 	if (code) {
 	    printf("bos_util: failed to set key, code %d.\n", code);
