@@ -12,11 +12,11 @@
  */
 
 #include <sys/types.h>
+#include <stdio.h>
+#include <string.h>
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/bucoord/dump_sched.c,v 1.9.6.3 2007/04/10 18:39:50 shadow Exp $");
 
 #ifdef AFS_NT40_ENV
 #include <winsock2.h>
@@ -33,16 +33,18 @@ RCSID
 #include <afs/bubasics.h>
 #include "bc.h"
 #include "error_macros.h"
+#include "bucoord_internal.h"
+#include "bucoord_prototypes.h"
 
 /* code to manage dump schedules 
  * specific to the ubik database implementation
  */
 
-afs_int32 bc_UpdateDumpSchedule();
 extern struct bc_config *bc_globalConfig;
 extern struct udbHandleS udbHandle;
 extern char *whoami;
 
+static int ListDumpSchedule(struct bc_dumpSchedule *adump, int alevel);
 
 /* ------------------------------------
  * command level routines
@@ -56,19 +58,15 @@ extern char *whoami;
  *	parm 1: expiration date (list)
  */
 
-afs_int32
-bc_AddDumpCmd(as, arock)
-     struct cmd_syndesc *as;
-     char *arock;
+int
+bc_AddDumpCmd(struct cmd_syndesc *as, void *arock)
 {
     register char *dname;	/* dump schedule name */
-    register afs_int32 code;
+    register int code;
     afs_int32 expType, expDate;
     register struct cmd_item *ti;
     udbClientTextP ctPtr;
 
-    afs_int32 bc_ParseExpiration();
-
     /* if an expiration date has been specified */
     if (as->parms[1].items) {
 	code = bc_ParseExpiration(&as->parms[1], &expType, &expDate);
@@ -146,16 +144,14 @@ bc_AddDumpCmd(as, arock)
  *	delete a dump schedule
  */
 
-afs_int32
-bc_DeleteDumpCmd(as, arock)
-     struct cmd_syndesc *as;
-     char *arock;
+int
+bc_DeleteDumpCmd(struct cmd_syndesc *as, void *arock)
 {
     /* parm 0 is vol set name
      * parm 1 is dump schedule name
      */
     register char *dname;
-    register afs_int32 code;
+    register int code;
     udbClientTextP ctPtr;
 
     /* lock schedules and check validity */
@@ -210,8 +206,6 @@ ListDumpSchedule(register struct bc_dumpSchedule *adump, int alevel)
     register int i;
     register struct bc_dumpSchedule *child;
 
-    char *tailCompPtr();
-
     /* sanity check for loops */
     if (alevel > 100) {
 	printf("backup: recursing listing dump schedule\n");
@@ -265,11 +259,11 @@ ListDumpSchedule(register struct bc_dumpSchedule *adump, int alevel)
  *      ignored
  */
 
-afs_int32
-bc_ListDumpScheduleCmd(struct cmd_syndesc *as, char *arock)
+int
+bc_ListDumpScheduleCmd(struct cmd_syndesc *as, void *arock)
 {
     /* no parms */
-    afs_int32 code;
+    int code;
     register struct bc_dumpSchedule *tdump;
 
     /* first check to see if schedules must be updated */
@@ -298,19 +292,15 @@ bc_ListDumpScheduleCmd(struct cmd_syndesc *as, char *arock)
  *	parm 1: expiration date (list)
  */
 
-afs_int32
-bc_SetExpCmd(as, arock)
-     struct cmd_syndesc *as;
-     char *arock;
+int
+bc_SetExpCmd(struct cmd_syndesc *as, void *arock)
 {
     register char *dname;	/* dump schedule name */
     register struct cmd_item *ti;
     struct bc_dumpSchedule *node, *parent;
     afs_int32 expType, expDate;
     udbClientTextP ctPtr;
-    register afs_int32 code;
-
-    afs_int32 bc_ParseExpiration();
+    register int code;
 
     /* if an expiration date has been specified */
     if (as->parms[1].items) {
@@ -382,7 +372,8 @@ bc_SetExpCmd(as, arock)
  * ------------------------------------
  */
 
-bc_ParseDumpSchedule()
+int
+bc_ParseDumpSchedule(void)
 {
     char tbuffer[1024];
     char dsname[256], period[64];
@@ -465,15 +456,14 @@ bc_ParseDumpSchedule()
     return 0;
 }
 
-
-bc_SaveDumpSchedule()
+int
+bc_SaveDumpSchedule(void)
 {
     struct bc_dumpSchedule *tdump;
     udbClientTextP ctPtr;
     afs_int32 code = 0;
 
     extern struct bc_config *bc_globalConfig;
-    extern afs_int32 filesize();
 
     /* setup the right ptr */
     ctPtr = &bc_globalConfig->configText[TB_DUMPSCHEDULE];
@@ -524,7 +514,7 @@ bc_SaveDumpSchedule()
  */
 
 afs_int32
-bc_UpdateDumpSchedule()
+bc_UpdateDumpSchedule(void)
 {
     struct bc_dumpSchedule *dumpPtr, *nextDumpPtr;
     struct udbHandleS *uhptr = &udbHandle;
