@@ -12,8 +12,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/butc/tcprocs.c,v 1.14.6.6 2008/10/27 23:41:45 shadow Exp $");
 
 #include <sys/types.h>
 #include <errno.h>
@@ -39,14 +37,16 @@ RCSID
 #include <afs/keys.h>
 #include <ubik.h>
 #include <afs/tcdata.h>
+#include <afs/budb_client.h>
+#include <afs/bucoord_prototypes.h>
 #include "error_macros.h"
 #include "butc_xbsa.h"
 #include "butc_prototypes.h"
-    
-static CopyDumpDesc();
-static CopyRestoreDesc();
-static CopyTapeSetDesc();
+#include "butc_internal.h"
 
+static int CopyDumpDesc(struct tc_dumpDesc *, tc_dumpArray *);
+static int CopyRestoreDesc(struct tc_restoreDesc *, tc_restoreArray *);
+static int CopyTapeSetDesc(struct tc_tapeSet *, struct tc_tapeSet *);
 
 int
 callPermitted(struct rx_call *call)
@@ -148,9 +148,6 @@ STC_LabelTape(struct rx_call *acid, struct tc_tapeLabel *label, afs_uint32 *task
     statusP statusPtr = NULL;
     afs_int32 code;
 
-    extern statusP createStatusNode();
-    extern afs_int32 allocTaskId();
-
 #ifdef xbsa
     if (CONF_XBSA)
 	return (TC_BADTASK);	/* LabelTape does not apply if XBSA */
@@ -227,8 +224,6 @@ STC_PerformDump(struct rx_call *rxCallId, struct tc_dumpInterface *tcdiPtr, tc_d
 #endif
     afs_int32 code = 0;
 
-    extern statusP createStatusNode();
-
     if (callPermitted(rxCallId) == 0)
 	return (TC_NOTPERMITTED);
 
@@ -325,8 +320,6 @@ STC_PerformRestore(struct rx_call *acid, char *dumpSetName, tc_restoreArray *are
     PROCESS pid;
 #endif
 
-    extern statusP createStatusNode();
-
     if (callPermitted(acid) == 0)
 	return (TC_NOTPERMITTED);
 
@@ -392,8 +385,6 @@ STC_ReadLabel(struct rx_call *acid, struct tc_tapeLabel *label, afs_uint32 *task
 {
     afs_int32 code;
 
-    extern int ReadLabel();
-
 #ifdef xbsa
     if (CONF_XBSA)
 	return (TC_BADTASK);	/* ReadLabel does not apply if XBSA */
@@ -423,9 +414,6 @@ STC_RestoreDb(struct rx_call *rxCall, afs_uint32 *taskId)
     statusP statusPtr;
     afs_int32 code = 0;
 
-    extern statusP createStatusNode();
-    extern afs_int32 allocTaskId();
-
 #ifdef xbsa
     if (CONF_XBSA)
 	return (TC_BADTASK);	/* LabelTape does not apply if XBSA */
@@ -493,9 +481,6 @@ STC_SaveDb(struct rx_call *rxCall, Date archiveTime, afs_uint32 *taskId)
     afs_int32 code = 0;
     struct saveDbIf *ptr;
 
-    extern statusP createStatusNode();
-    extern afs_int32 allocTaskId();
-
 #ifdef xbsa
     if (CONF_XBSA)
 	return (TC_BADTASK);	/* LabelTape does not apply if XBSA */
@@ -575,9 +560,6 @@ STC_ScanDumps(struct rx_call *acid, afs_int32 addDbFlag, afs_uint32 *taskId)
     statusP statusPtr = NULL;
     afs_int32 code = 0;
 
-    extern afs_int32 allocTaskId();
-    extern statusP createStatusNode();
-
 #ifdef xbsa
     if (CONF_XBSA)
 	return (TC_BADTASK);	/* ScanDumps does not apply if XBSA */
@@ -654,10 +636,10 @@ STC_TCInfo(struct rx_call *acid, struct tc_tcInfo *tciptr)
 afs_int32
 STC_DeleteDump(struct rx_call *acid, afs_uint32 dumpID, afs_uint32 *taskId)
 {
-    struct deleteDumpIf *ptr = 0;
-    statusP statusPtr = 0;
     afs_int32 code = TC_BADTASK;	/* If not compiled -Dxbsa then fail */
 #ifdef xbsa
+    struct deleteDumpIf *ptr = 0;
+    statusP statusPtr = 0;
 #ifdef AFS_PTHREAD_ENV
     pthread_t pid;
     pthread_attr_t tattr;
@@ -666,8 +648,6 @@ STC_DeleteDump(struct rx_call *acid, afs_uint32 dumpID, afs_uint32 *taskId)
     PROCESS pid;
 #endif
 #endif
-    extern statusP createStatusNode();
-    extern afs_int32 allocTaskId();
 
     *taskId = 0;
     if (!CONF_XBSA)
