@@ -15,8 +15,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/gtx/textobject.c,v 1.6.14.3 2009/03/16 13:49:32 shadow Exp $");
 
 #include "gtxtextobj.h"		/*Interface for this module */
 #include "gtxwindows.h"		/*Gator window interface */
@@ -438,7 +436,7 @@ gator_text_Write(struct onode *onp, char *strToWrite, int numChars,
 		"[%s:%s] Writing %d chars to text object at %p (highlight=%d, skip=%d: '",
 		mn, rn, numChars, onp, highlight, skip);
 	for (i = 0; i < numChars; i++)
-	    fprintf(stderr, "%c", strToWrite + i);
+	    fprintf(stderr, "%c", strToWrite[i]);
 	fprintf(stderr, "\n");
     }
 
