@@ -10,8 +10,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/kauth/rebuild.c,v 1.13.2.6 2009/03/17 04:45:10 shadow Exp $");
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -29,6 +27,9 @@ RCSID
 #include <time.h>
 #include <ubik.h>
 #include <afs/cmd.h>
+#include <des.h>
+#include <des_prototypes.h>
+#include <rx/rxkad.h>
 
 #include <afs/com_err.h>
 
@@ -469,8 +470,8 @@ WorkerBee(struct cmd_syndesc *as, void *arock)
 		    printf("Entry %d has zero length name\n", i);
 		continue;
 	    }
-	    if (!des_check_key_parity(&entry.key)
-		|| des_is_weak_key(&entry.key)) {
+	    if (!des_check_key_parity(ktc_to_cblock(&entry.key))
+		|| des_is_weak_key(ktc_to_cblock(&entry.key))) {
 		fprintf(stderr, "Entry %d, %s, has bad key\n", i,
 			EntryName(&entry));
 		continue;
