@@ -31,17 +31,19 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/ptserver/map.c,v 1.3.14.2 2007/08/11 23:41:37 jaltman Exp $");
 
 #ifdef SUPERGROUPS
 #include <errno.h>
 #include "map.h"
+#ifdef STDLIB_HAS_MALLOC_PROTOS
+#include <stdlib.h>
+#else
 #include "malloc.h"
+#endif
 
 #undef PRINT_MAP_ERROR
-/* #define MAP_DEBUG /**/
-/* #define NEED_READ_WRITE /**/
+/* #define MAP_DEBUG */
+/* #define NEED_READ_WRITE */
 
 #define LSHIFT 5
 #define MSHIFT 8		/* XXX make this 8 in the production version... */
