@@ -217,6 +217,8 @@ extern afs_int32 rx_GetServerPeers(osi_socket socket, afs_uint32 remoteAddr,
 				   afs_uint32 debugSupportedValues,
 				   struct rx_debugPeer *peer,
 				   afs_uint32 * supportedValues);
+extern afs_int32 rx_GetLocalPeers(afs_uint32 peerHost, afs_uint16 peerPort,
+				      struct rx_debugPeer * peerStats);
 extern void shutdown_rx(void);
 #ifndef osirx_AssertMine
 extern void osirx_AssertMine(afs_kmutex_t * lockaddr, char *msg);
@@ -278,6 +280,9 @@ extern int clock_UnInit(void);
 #if !defined(clock_UpdateTime)
 extern void clock_UpdateTime(void);
 #endif
+#if defined(UKERNEL) && !defined(osi_GetTime)
+extern int osi_GetTime(struct timeval *tv);
+#endif
 
 /* rx_clock_nt.c */
 
@@ -363,12 +368,16 @@ extern osi_socket rxi_GetHostUDPSocket(u_int host, u_short port);
 #define osi_Assert(expr) \
     do { if (!(expr)) { osi_AssertFailK(#expr, __FILE__, __LINE__); BUG(); } } while (0)
 #else
-#if defined(KERNEL) && defined(AFS_AIX_ENV)
+#if defined(KERNEL) && (defined(AFS_AIX_ENV) && !defined(AFS_AIX61_ENV))
 extern void osi_Panic(char *fmt, void *a1, void *a2, void *a3);
 #else
+#ifdef AFS_AIX61_ENV
+/* No prototype. Deliberate, since there's no vprintf et al */
+#else
 extern void osi_Panic(char *fmt, ...);
 #endif
 #endif
+#endif
 extern int osi_utoa(char *buf, size_t len, unsigned long val);
 extern void rxi_InitPeerParams(struct rx_peer *pp);
 extern void shutdown_rxkernel(void);
@@ -432,6 +441,11 @@ extern struct afs_ifinfo afsifinfo[ADDRSPERSITE];
 #endif
 extern void osi_StopListener(void);
 extern int rxi_FindIfMTU(afs_uint32 addr);
+#if defined(UKERNEL)
+extern void rxi_ListenerProc(osi_socket usockp, int *tnop,
+			     struct rx_call **newcallp);
+#endif
+
 #ifndef RXK_LISTENER_ENV
 extern void rxk_init();
 #endif
@@ -564,7 +578,6 @@ extern int rxi_Listen(osi_socket sock);
 extern int rxi_Recvmsg(osi_socket socket, struct msghdr *msg_p, int flags);
 extern int rxi_Sendmsg(osi_socket socket, struct msghdr *msg_p, int flags);
 
-
 /* rx_rdwr.c */
 extern int rxi_ReadProc(struct rx_call *call, char *buf,
 			int nbytes);
