@@ -14,8 +14,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/vol/ihandle.c,v 1.19.8.7 2009/05/22 16:00:35 shadow Exp $");
 
 #include <stdio.h>
 #include <sys/types.h>
@@ -98,7 +96,7 @@ void *ih_sync_thread(void *);
 #ifdef AFS_PTHREAD_ENV
 /* Initialize the global ihandle mutex */
 void
-ih_glock_init()
+ih_glock_init(void)
 {
     assert(pthread_mutex_init(&ih_glock_mutex, NULL) == 0);
 }
